import { select, csv, max } from 'd3';
csv('data.csv').then((data) => {
  data.forEach((d) => {
    console.log(d.Country, 
                d['2022 Population']);
  });
  render(data);
});

const render = (data) => {
const width = 3000;
const height = 600;
const margin = { top: 50, bottom: 200, left: 150, right: 100 };

const svg = d3.select('#d3-container')
  .append('svg')
  .attr('width', width - margin.left - margin.right)
  .attr('height', height - margin.top - margin.bottom)
  .attr("viewBox", [0, 0, width, height]);

const x = d3.scaleBand()
  .domain(d3.range(data.length))
  .range([margin.left, width - margin.right])
  .padding(0.1)

const y = d3.scaleLinear()
  .domain([0, max(data, (d) => +d["2022 Population"])])
  .range([height - margin.bottom, margin.top])

svg
  .append("g")
  .attr("fill", 'royalblue')
  .selectAll("rect")
  .data(data.sort((a, b) => d3.descending(a["2022 Population"], b["2022 Population"])))
  .join("rect")
    .attr("x", (d, i) => x(i))
    .attr("y", d => y(d["2022 Population"]))
    .attr('title', (d) => d["2022 Population"])
    .attr("class", "rect")
    .attr("height", d => y(0) - y(d["2022 Population"]))
    .attr("width", x.bandwidth());

function yAxis(g) {
  g.attr("transform", `translate(${margin.left}, 0)`)
    .call(d3.axisLeft(y).ticks(null, data.format))
    .attr("font-size", '20px')
}

function xAxis(g) {
  g.attr("transform", `translate(0,${height - margin.bottom})`)
    .call(d3.axisBottom(x).tickFormat(i => data[i].Country))
    .attr("font-size", '20px')
  	.selectAll("text")    
            .style("text-anchor", "end")
            .attr("dx", "-.8em")
            .attr("dy", ".15em")
            .attr("transform", "rotate(-65)");
}

svg.append("g").call(xAxis);
svg.append("g").call(yAxis);
svg.node();
	}

